@@ -10,10 +10,10 @@ module OmniAuth
         OmniAuth::Strategy.included(subclass)
       end
 
-      OTHER_REQUEST_OPTIONS = [:skip_conditions, :allowed_clock_drift, :matches_request_id, :skip_subject_confirmation].freeze
+      RUBYSAML_RESPONSE_OPTIONS = OneLogin::RubySaml::Response::AVAILABLE_OPTIONS
 
       option :name_identifier_format, nil
-      option :idp_sso_target_url_runtime_params, {}
+      option :idp_sso_service_url_runtime_params, {}
       option :request_attributes, [
         { :name => 'email', :name_format => 'urn:oasis:names:tc:SAML:2.0:attrname-format:basic', :friendly_name => 'Email address' },
         { :name => 'name', :name_format => 'urn:oasis:names:tc:SAML:2.0:attrname-format:basic', :friendly_name => 'Full name' },
@@ -177,7 +177,7 @@ module OmniAuth
       end
 
       def handle_logout_request(raw_request, settings)
-        logout_request = OneLogin::RubySaml::SloLogoutrequest.new(raw_request)
+        logout_request = OneLogin::RubySaml::SloLogoutrequest.new(raw_request, {}.merge(settings: settings).merge(get_params: @request.params))
 
         if logout_request.is_valid? &&
           logout_request.name_id == session["saml_uid"]
@@ -231,7 +231,7 @@ module OmniAuth
 
       def options_for_response_object
         # filter options to select only extra parameters
-        opts = options.select {|k,_| OTHER_REQUEST_OPTIONS.include?(k.to_sym)}
+        opts = options.select {|k,_| RUBYSAML_RESPONSE_OPTIONS.include?(k.to_sym)}
 
         # symbolize keys without activeSupport/symbolize_keys (ruby-saml use symbols)
         opts.inject({}) do |new_hash, (key, value)|
@@ -264,7 +264,7 @@ module OmniAuth
       end
 
       def other_phase_for_spslo
-        if options.idp_slo_target_url
+        if options.idp_slo_service_url
           with_settings do |settings|
             redirect(generate_logout_request(settings))
           end
@@ -275,7 +275,7 @@ module OmniAuth
 
       def add_request_attributes_to(settings)
         settings.attribute_consuming_service.service_name options.attribute_service_name
-        settings.issuer = options.issuer
+        settings.sp_entity_id = options.sp_entity_id
 
         options.request_attributes.each do |attribute|
           settings.attribute_consuming_service.add_attribute attribute
@@ -284,7 +284,7 @@ module OmniAuth
 
       def additional_params_for_authn_request
         {}.tap do |additional_params|
-          runtime_request_parameters = options.delete(:idp_sso_target_url_runtime_params)
+          runtime_request_parameters = options.delete(:idp_sso_service_url_runtime_params)
 
           if runtime_request_parameters
             runtime_request_parameters.each_pair do |request_param_key, mapped_param_key|
